%define majver %(echo %version | cut -d. -f 1-2)
%define pppdver %(rpm -q --queryformat '%%{version}\\n' ppp | head -n1)
Name:          NetworkManager
Version:       1.48.4
Release:       1mamba
Summary:       A hardware level network management tool integrated with D-Bus
Group:         System/Kernel and Hardware
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://networkmanager.dev/
Source:        https://download.gnome.org/sources/NetworkManager/%{majver}/%{name}-%{version}.tar.xz
Source1:       NetworkManager-0.8.2-polkit-localauthority.patch
Source2:       NetworkManager-connectivity-openmamba.conf
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libaudit-devel
BuildRequires: libbluetooth-devel
BuildRequires: libcurl-devel
BuildRequires: libglib-devel
BuildRequires: libjansson-devel
BuildRequires: libmm-devel
BuildRequires: libndp-devel
BuildRequires: libnewt-devel
BuildRequires: libnspr-devel
BuildRequires: libnss-devel
BuildRequires: libpsl-devel
BuildRequires: libreadline-devel
BuildRequires: libselinux-devel
BuildRequires: libsystemd-devel
BuildRequires: libteam-devel
BuildRequires: libudev-devel
## AUTOBUILDREQ-END
BuildRequires: libsodium-devel >= 1.0.8-1mamba
BuildRequires: gettext-devel
BuildRequires: pkgconfig
BuildRequires: dhcdbd
BuildRequires: dhcp-client
BuildRequires: libiw-devel
BuildRequires: ppp-devel
BuildRequires: libpsl-devel
BuildRequires: pygobject-py3
Requires:      iproute >= 2.6.11
Requires:      wpa_supplicant >= 0.7.3-3mamba
Requires:      ppp >= 2.4.5-5mamba
Requires:      dhcpclient
Requires:      dnsmasq
Requires:      libnm = %{?epoch:%epoch:}%{version}-%{release}
Requires(post):dbus
Requires(post):systemd-core
Conflicts:     wicd
%systemd_requires

%description
NetworkManager is a hardware level network management tool integrated with the D-Bus subsystem.

%package -n libnm
Summary:       Libraries used by %{name}
Group:         System/Libraries

%description -n libnm
NetworkManager is a hardware level network management tool integrated with the D-Bus subsystem.
This package contains the shared libraries.

%package -n libnm-devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      libnm = %{?epoch:%epoch:}%{version}-%{release}
Provides:      NetworkManager-devel
Obsoletes:     NetworkManager-devel < 1.30.4

%description -n libnm-devel
NetworkManager is a hardware level network management tool integrated with the D-Bus subsystem.
This package contains static libraries and header files needed for development.

%package apidocs
Group:         Documentation
Summary:       %{name} API documentation
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      gtk-doc

%description apidocs
This package includes the %{name} API documentation.

%debug_package

%prep
%setup -q
#-D -T

%build
#:<< _EOF
%meson \
   --libexecdir %{_prefix}/libexec \
   -D udev_dir=%{_prefix}/lib/udev \
   -D tests=yes \
   -D docs=true \
   -D ifcfg_rh=true \
   -D systemdsystemunitdir=%{_unitdir} \
   -D session_tracking=systemd \
   -D session_tracking_consolekit=false \
   -D modem_manager=true \
   -D bluez5_dun=true \
   -D teamdctl=true \
   -D polkit=true \
   -D modify_system=true \
   -D concheck=true \
   -D wifi=true \
   -D suspend_resume=systemd \
   -D iwd=true \
   -D config_plugins_default=keyfile \
   -D vapi=true \
   -D more_asserts=no \
   -D more_logging=false \
   -D qt=false \
   -D pppd=%{_sbindir}/pppd \
   -D pppd_plugin_dir=%{_libdir}/pppd/%{pppdver}

%meson_build

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%meson_install

#install -m0755 test/.libs/nm-online %{buildroot}%{_bindir}/nm-online
install -D -m0644 %{SOURCE1} \
   %{buildroot}%{_sysconfdir}/polkit-1/localauthority/50-local.d/10-org-freedesktop-network-manager-settings.pkla
rm -f %{buildroot}%{_libdir}/libnm-*.a

# Install hotspot connectivity check
install -D -m0644 %{SOURCE2} \
   %{buildroot}%{_sysconfdir}/NetworkManager/conf.d/20-connectivity-openmamba.conf

%{find_lang} %{name}

cat > %{buildroot}%{_sysconfdir}/NetworkManager/NetworkManager.conf << _EOF
[main]
plugins=keyfile,ifcfg-rh
_EOF

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post
/sbin/ldconfig
if [ $1 -gt 1 ]; then
   # Switch to keyfile as default, ifcfg-rh kept for legacy
   sed -i "s|plugins=ifcfg-rh,keyfile|plugins=keyfile,ifcfg-rh|" %{_sysconfdir}/NetworkManager/NetworkManager.conf
fi
if [ $1 -ge 1 ]; then
   # clean old sysv broken links
   find /etc/rc[0-6].d/ -type l -xtype l -exec rm -f {} \;
   sed -i "s|^plugins=keyfile$|plugins=keyfile,ifcfg-rh|" %{_sysconfdir}/NetworkManager/NetworkManager.conf
   systemctl -q enable NetworkManager
   systemctl -q enable NetworkManager-dispatcher
   systemctl -q daemon-reload
fi
if [ $1 -eq 1 ]; then
   # new install
   systemctl -q start NetworkManager
fi
:

%preun
# erase
/sbin/ldconfig
if [ $1 -eq 0 ]; then
   systemctl -q stop NetworkManager-dispatcher
   systemctl -q stop NetworkManager
   systemctl -q disable NetworkManager
   systemctl -q disable NetworkManager-dispatcher
fi
:

%files -f %{name}.lang
%defattr(-,root,root)
%{_sysconfdir}/polkit-1/localauthority/50-local.d/10-org-freedesktop-network-manager-settings.pkla
%dir %{_sysconfdir}/NetworkManager
%config(noreplace) %{_sysconfdir}/NetworkManager/NetworkManager.conf
%dir %{_sysconfdir}/NetworkManager/conf.d
%config(noreplace) %{_sysconfdir}/NetworkManager/conf.d/20-connectivity-openmamba.conf
%dir %{_sysconfdir}/NetworkManager/dispatcher.d
%dir %{_sysconfdir}/NetworkManager/dispatcher.d/*.d
%dir %{_sysconfdir}/NetworkManager/dnsmasq-shared.d
%dir %{_sysconfdir}/NetworkManager/dnsmasq.d
%dir %{_sysconfdir}/NetworkManager/system-connections
#%dir %{_sysconfdir}/NetworkManager/VPN
%dir %{_sysconfdir}/sysconfig/network-scripts
%{_sbindir}/NetworkManager
%{_bindir}/nmcli
%{_bindir}/nmtui
%{_bindir}/nmtui-connect
%{_bindir}/nmtui-edit
%{_bindir}/nmtui-hostname
%{_bindir}/nm-online
%{_udevrulesdir}/*.rules
%{_prefix}/lib/firewalld/zones/nm-shared.xml
%{_prefix}/libexec/nm-*
%dir %{_prefix}/lib/NetworkManager
%dir %{_prefix}/lib/NetworkManager/dispatcher.d
%{_prefix}/lib/NetworkManager/dispatcher.d/*
%{_unitdir}/NetworkManager.service
%{_unitdir}/NetworkManager-dispatcher.service
%{_unitdir}/NetworkManager-wait-online.service
%{_unitdir}/nm-cloud-setup.service
%{_unitdir}/nm-cloud-setup.timer
%{_unitdir}/nm-priv-helper.service
%{_unitdir}/NetworkManager.service.d/NetworkManager-ovs.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.NetworkManager*.xml
%{_datadir}/dbus-1/system.d/nm-*.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.NetworkManager.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.nm*.service
%{_datadir}/bash-completion/completions/nmcli
%{_datadir}/polkit-1/actions/org.freedesktop.NetworkManager.policy
%{_mandir}/man1/nm-online.1.*
%{_mandir}/man1/nmcli.1*
%{_mandir}/man1/nmtui*.1*
%{_mandir}/man5/NetworkManager.conf.5*
%{_mandir}/man5/nm-settings*.5*
%{_mandir}/man5/nm-system-settings.conf.5*
%{_mandir}/man7/nmcli-examples.7*
%{_mandir}/man7/nm-openvswitch.7*
%{_mandir}/man8/NetworkManager*.8*
%{_mandir}/man8/nm-initrd-generator.8*
%{_mandir}/man8/nm-cloud-setup.8*

%files -n libnm
%defattr(-,root,root)
%{_libdir}/libnm.so.*
%dir %{_libdir}/NetworkManager
%{_libdir}/NetworkManager/%{version}/libnm-device-plugin-*.so
%{_libdir}/NetworkManager/%{version}/libnm-settings-plugin-*.so
%{_libdir}/NetworkManager/%{version}/libnm-ppp-plugin.so
%{_libdir}/NetworkManager/%{version}/libnm-wwan.so
%{_libdir}/pppd/*/nm-pppd-plugin.so
%{_libdir}/girepository-1.0/NM-1.0.typelib
%doc AUTHORS COPYING

%files -n libnm-devel
%defattr(-,root,root)
%dir %{_includedir}/libnm
%{_includedir}/libnm/*.h
%{_libdir}/libnm.so
%{_datadir}/gir-1.0/NM-1.0.gir
%{_datadir}/vala/vapi/libnm.deps
%{_datadir}/vala/vapi/libnm.vapi
%{_libdir}/pkgconfig/*.pc
%doc ChangeLog NEWS README.md TODO

%files apidocs
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc/html/NetworkManager
%{_datadir}/gtk-doc/html/NetworkManager/*
%dir %{_datadir}/gtk-doc/html/libnm
%{_datadir}/gtk-doc/html/libnm/*
%dir %{_datadir}/doc/NetworkManager
%dir %{_datadir}/doc/NetworkManager/examples
%{_datadir}/doc/NetworkManager/examples/server.conf

%changelog
* Sat Jul 06 2024 Automatic Build System <autodist@openmamba.org> 1.48.4-1mamba
- automatic version update by autodist

* Mon Jun 24 2024 Automatic Build System <autodist@openmamba.org> 1.48.2-1mamba
- automatic version update by autodist

* Sat Jun 01 2024 Automatic Build System <autodist@openmamba.org> 1.48.0-1mamba
- automatic version update by autodist

* Wed May 15 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 1.46.0-4mamba
- update hotspot connectivity check from https to a http url

* Tue May 14 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 1.46.0-3mamba
- install hotspot connectivity check conf.d file for openmamba

* Thu Mar 07 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 1.46.0-2mamba
- fix ipv4 dhcp disabling ebpf (see https://gitlab.freedesktop.org/NetworkManager/NetworkManager/-/issues/1485#note_2297552 )

* Thu Feb 22 2024 Automatic Build System <autodist@openmamba.org> 1.46.0-1mamba
- automatic version update by autodist

* Wed Nov 01 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 1.44.2-1mamba
- update to 1.44.2

* Tue Aug 15 2023 Automatic Build System <autodist@mambasoft.it> 1.44.0-1mamba
- automatic version update by autodist

* Thu Jun 29 2023 Automatic Build System <autodist@mambasoft.it> 1.42.8-1mamba
- automatic version update by autodist

* Fri Apr 21 2023 Automatic Build System <autodist@mambasoft.it> 1.42.6-1mamba
- automatic version update by autodist

* Thu Mar 09 2023 Automatic Build System <autodist@mambasoft.it> 1.42.4-1mamba
- automatic version update by autodist

* Thu Feb 23 2023 Automatic Build System <autodist@mambasoft.it> 1.42.2-1mamba
- automatic version update by autodist

* Fri Feb 10 2023 Automatic Build System <autodist@mambasoft.it> 1.42.0-1mamba
- automatic version update by autodist

* Fri Jan 27 2023 Automatic Build System <autodist@mambasoft.it> 1.40.12-1mamba
- automatic version update by autodist

* Sat Jan 21 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 1.40.10-2mamba
- set configuration backends from ifcfg_rh,keyfile to keyfile,ifcfg_rh
- install some missing empty directories in /etc/NetworkManager and /etc/sysconfig

* Wed Jan 11 2023 Automatic Build System <autodist@mambasoft.it> 1.40.10-1mamba
- automatic version update by autodist

* Sat Dec 17 2022 Automatic Build System <autodist@mambasoft.it> 1.40.8-1mamba
- automatic version update by autodist

* Thu Dec 01 2022 Automatic Build System <autodist@mambasoft.it> 1.40.6-1mamba
- automatic version update by autodist

* Wed Nov 23 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 1.40.4-2mamba
- x86_64, aarch64: force setting libexecdir as /usr/libexec to fix compatibility with dracut module

* Sat Nov 19 2022 Automatic Build System <autodist@mambasoft.it> 1.40.4-1mamba
- automatic version update by autodist

* Wed Oct 19 2022 Automatic Build System <autodist@mambasoft.it> 1.40.2-1mamba
- automatic version update by autodist

* Sat Aug 27 2022 Automatic Build System <autodist@mambasoft.it> 1.40.0-1mamba
- automatic version update by autodist

* Fri Aug 12 2022 Automatic Build System <autodist@mambasoft.it> 1.38.4-1mamba
- automatic version update by autodist

* Fri Jun 17 2022 Automatic Build System <autodist@mambasoft.it> 1.38.2-1mamba
- automatic version update by autodist

* Sat May 14 2022 Automatic Build System <autodist@mambasoft.it> 1.38.0-1mamba
- automatic version update by autodist

* Wed Mar 23 2022 Automatic Build System <autodist@mambasoft.it> 1.36.4-1mamba
- automatic version update by autodist

* Mon Mar 07 2022 Automatic Build System <autodist@mambasoft.it> 1.36.2-1mamba
- automatic version update by autodist

* Sat Feb 26 2022 Automatic Build System <autodist@mambasoft.it> 1.36.0-1mamba
- automatic version update by autodist

* Wed Sep 22 2021 Automatic Build System <autodist@mambasoft.it> 1.32.12-1mamba
- automatic version update by autodist

* Fri Aug 20 2021 Automatic Build System <autodist@mambasoft.it> 1.32.10-1mamba
- automatic version update by autodist

* Wed Aug 11 2021 Automatic Build System <autodist@mambasoft.it> 1.32.8-1mamba
- automatic version update by autodist

* Thu Jul 29 2021 Automatic Build System <autodist@mambasoft.it> 1.32.6-1mamba
- automatic version update by autodist

* Wed Jul 21 2021 Automatic Build System <autodist@mambasoft.it> 1.32.4-1mamba
- automatic version update by autodist

* Thu Jul 01 2021 Automatic Build System <autodist@mambasoft.it> 1.32.2-1mamba
- automatic version update by autodist

* Sat Jun 19 2021 Automatic Build System <autodist@mambasoft.it> 1.32.0-1mamba
- automatic version update by autodist

* Thu Apr 22 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 1.30.4-2mamba
- fix udev libdir

* Tue Apr 20 2021 Automatic Build System <autodist@mambasoft.it> 1.30.4-1mamba
- automatic version update by autodist

* Sat Mar 13 2021 Automatic Build System <autodist@mambasoft.it> 1.30.2-1mamba
- automatic version update by autodist

* Wed Mar 03 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 1.30.0-2mamba
- require dnsmasq required e.g. for hotspot functionality

* Fri Feb 19 2021 Automatic Build System <autodist@mambasoft.it> 1.30.0-1mamba
- automatic version update by autodist

* Mon Dec 07 2020 Automatic Build System <autodist@mambasoft.it> 1.28.0-1mamba
- automatic version update by autodist

* Thu Oct 15 2020 Automatic Build System <autodist@mambasoft.it> 1.26.4-1mamba
- automatic version update by autodist

* Thu Aug 20 2020 Automatic Build System <autodist@mambasoft.it> 1.26.2-1mamba
- automatic version update by autodist

* Tue Jul 14 2020 Automatic Build System <autodist@mambasoft.it> 1.26.0-1mamba
- automatic version update by autodist

* Sat Jun 06 2020 Automatic Build System <autodist@mambasoft.it> 1.24.2-1mamba
- automatic version update by autodist

* Sat May 09 2020 Automatic Build System <autodist@mambasoft.it> 1.24.0-1mamba
- automatic version update by autodist

* Fri Mar 13 2020 Automatic Build System <autodist@mambasoft.it> 1.22.10-1mamba
- automatic version update by autodist

* Wed Feb 19 2020 Automatic Build System <autodist@mambasoft.it> 1.22.8-1mamba
- automatic version update by autodist

* Wed Feb 05 2020 Automatic Build System <autodist@mambasoft.it> 1.22.6-1mamba
- automatic version update by autodist

* Fri Jan 10 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 1.22.4-1mamba
- update to 1.22.4

* Tue Dec 24 2019 Automatic Build System <autodist@mambasoft.it> 1.22.2-1mamba
- automatic version update by autodist

* Tue Dec 17 2019 Automatic Build System <autodist@mambasoft.it> 1.22.0-1mamba
- automatic version update by autodist

* Mon Nov 25 2019 Automatic Build System <autodist@mambasoft.it> 1.20.8-1mamba
- automatic version update by autodist

* Thu Nov 07 2019 Automatic Build System <autodist@mambasoft.it> 1.20.6-1mamba
- automatic version update by autodist

* Sun Oct 27 2019 Automatic Build System <autodist@mambasoft.it> 1.20.4-1mamba
- automatic version update by autodist

* Thu Jul 25 2019 Automatic Build System <autodist@mambasoft.it> 1.18.2-1mamba
- automatic version update by autodist

* Thu Jul 25 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.18.1-3mamba
- x86_64: rebuild after rpm fix for _libexecdir

* Mon Jul 22 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.18.1-2mamba
- rebuilt with rpm4 to remove requirement for rpmlib(PartialHardlinkSets) <= 4.0.4-1

* Sun Apr 21 2019 Automatic Build System <autodist@mambasoft.it> 1.18.1-1mamba
- automatic version update by autodist

* Mon Mar 25 2019 Automatic Build System <autodist@mambasoft.it> 1.16.0-1mamba
- automatic version update by autodist

* Sun Nov 04 2018 Automatic Build System <autodist@mambasoft.it> 1.14.4-1mamba
- automatic version update by autodist

* Fri Sep 14 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.12.2-3mamba
- rebuilt with --enable-config-plugin-ibft and --enable-polkit-agent

* Thu Sep 06 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.12.2-2mamba
- rebuilt with --enable-libnm-glib

* Thu Jul 26 2018 Automatic Build System <autodist@mambasoft.it> 1.12.2-1mamba
- automatic version update by autodist

* Sun Jul 08 2018 Automatic Build System <autodist@mambasoft.it> 1.12.0-1mamba
- automatic version update by autodist

* Sat Jun 16 2018 Automatic Build System <autodist@mambasoft.it> 1.10.10-1mamba
- automatic version update by autodist

* Fri May 11 2018 Automatic Build System <autodist@mambasoft.it> 1.10.8-1mamba
- automatic version update by autodist

* Sun Apr 15 2018 Automatic Build System <autodist@mambasoft.it> 1.10.6-1mamba
- automatic version update by autodist

* Mon Dec 05 2016 Automatic Build System <autodist@mambasoft.it> 1.4.2-1mamba
- automatic version update by autodist

* Thu Aug 25 2016 Automatic Build System <autodist@mambasoft.it> 1.4.0-1mamba
- automatic version update by autodist

* Thu Aug 04 2016 Automatic Build System <autodist@mambasoft.it> 1.2.4-1mamba
- automatic version update by autodist

* Tue Jun 07 2016 Automatic Build System <autodist@mambasoft.it> 1.2.2-1mamba
- automatic version update by autodist

* Mon May 16 2016 Automatic Build System <autodist@mambasoft.it> 1.2.0-1mamba
- automatic version update by autodist

* Sat Apr 02 2016 Automatic Build System <autodist@mambasoft.it> 1.0.12-1mamba
- automatic version update by autodist

* Mon Feb 29 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.10-2mamba
- rebuilt by autoport with build requirements: libsodium-devel>=1.0.8-1mamba

* Thu Dec 24 2015 Automatic Build System <autodist@mambasoft.it> 1.0.10-1mamba
- automatic version update by autodist

* Fri Nov 27 2015 Automatic Build System <autodist@mambasoft.it> 1.0.8-1mamba
- automatic version update by autodist

* Fri Aug 28 2015 Automatic Build System <autodist@mambasoft.it> 1.0.6-1mamba
- automatic version update by autodist

* Sun Aug 02 2015 Automatic Build System <autodist@mambasoft.it> 1.0.4-1mamba
- automatic version update by autodist

* Wed May 06 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2-1mamba
- automatic version update by autodist

* Sun Dec 28 2014 Automatic Build System <autodist@mambasoft.it> 1.0.0-1mamba
- automatic version update by autodist

* Sat Nov 22 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.10.0-3mamba
- patch systemd service with After=dbus.service to fix blocking shutdowns
- remove sysv initscript

* Thu Oct 16 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.10.0-2mamba
- rebuilt with --with-session-tracking=systemd and more new options

* Fri Jul 04 2014 Automatic Build System <autodist@mambasoft.it> 0.9.10.0-1mamba
- automatic version update by autodist

* Sat Jun 21 2014 Automatic Build System <autodist@mambasoft.it> 0.9.9.98-1mamba
- automatic version update by autodist

* Wed Jun 18 2014 Automatic Build System <autodist@mambasoft.it> 0.9.9.95-1mamba
- automatic version update by autodist

* Thu Apr 24 2014 Automatic Build System <autodist@mambasoft.it> 0.9.8.10-1mamba
- automatic version update by autodist

* Mon Apr 07 2014 Automatic Build System <autodist@mambasoft.it> 0.9.8.9-1mamba
- automatic version update by autodist

* Sun Dec 01 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.8-3mamba
- enable bluez4 support

* Sat Nov 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.8-2mamba
- rebuilt with --with-modem-manager-1 to support ModemManager 1.0

* Fri Oct 11 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.8-1mamba
- automatic version update by autodist

* Tue Oct 01 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.6-1mamba
- automatic version update by autodist

* Sat Sep 14 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.4-1mamba
- automatic version update by autodist

* Wed Sep 11 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.2-3mamba
- also enable NetworkManager-dispatcher service for dispatcher function to work
  (https://bugzilla.redhat.com/show_bug.cgi?id=974811)

* Fri Aug 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.2-2mamba
- polkit: allo action org.freedesktop.NetworkManager.settings.modify.system to sysadmin as required by network-manager-applet

* Sat Jun 08 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.2-1mamba
- automatic version update by autodist

* Thu Mar 21 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.0-4mamba
- enable systemd NetworkManager service

* Sun Mar 17 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.0-3mamba
- fix systemdsystemunitdir installation path

* Mon Feb 25 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.0-2mamba
- install initscript, no longer installed by default

* Sat Feb 23 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.0-1mamba
- automatic version update by autodist

* Tue Jan 22 2013 Automatic Build System <autodist@mambasoft.it> 0.9.7.995-1mamba
- automatic version update by autodist

* Mon Oct 29 2012 Automatic Build System <autodist@mambasoft.it> 0.9.6.4-1mamba
- automatic version update by autodist
- source edit: require ppp > 2.4.5-5mamba (with ipv6 support enabled)

* Sat Sep 15 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.6.0-2mamba
- moved typelib files from libnm-devel to libnm

* Tue Aug 07 2012 Automatic Build System <autodist@mambasoft.it> 0.9.6.0-1mamba
- automatic version update by autodist

* Tue Jul 24 2012 Automatic Build System <autodist@mambasoft.it> 0.9.5.96-1mamba
- automatic version update by autodist

* Sat Jun 30 2012 Automatic Build System <autodist@mambasoft.it> 0.9.5.95-1mamba
- automatic version update by autodist

* Sat Jun 09 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.4.0-4mamba
- use lfs patch to fix nmcli issues

* Fri May 18 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.4.0-3mamba
- added upstream patch to fix nmcli (http://cgit.freedesktop.org/NetworkManager/NetworkManager/commit/?id=8a2267ab6b37948a70c10f0af781be4822a54c6b)

* Thu May 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.4.0-2mamba
- added patch to raise wpa_supplicant timeout from 25 to 90 seconds
- fixed installation of nm-online tool
- don't restart service on upgrade

* Sat Mar 24 2012 Automatic Build System <autodist@mambasoft.it> 0.9.4.0-1mamba
- automatic version update by autodist

* Mon Mar 19 2012 Automatic Build System <autodist@mambasoft.it> 0.9.3.997-1mamba
- automatic version update by autodist

* Tue Mar 13 2012 Automatic Build System <autodist@mambasoft.it> 0.9.3.995-1mamba
- automatic version update by autodist

* Thu Nov 10 2011 Automatic Build System <autodist@mambasoft.it> 0.9.2.0-1mamba
- automatic version update by autodist

* Sat Oct 29 2011 Automatic Build System <autodist@mambasoft.it> 0.9.1.95-1mamba
- automatic version update by autodist

* Wed Sep 28 2011 Automatic Build System <autodist@mambasoft.it> 0.9.1.90-1mamba
- automatic version update by autodist

* Sun Sep 18 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.0-2mamba
- require wpa_supplicant >= 0.7.3-3mamba

* Thu Aug 25 2011 Automatic Build System <autodist@mambasoft.it> 0.9.0-1mamba
- automatic version update by autodist

* Thu May 12 2011 Automatic Build System <autodist@mambasoft.it> 0.8.4.0-1mamba
- automatic update by autodist

* Fri Apr 29 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-12mamba
- Added patch reconnect_if_modem to avoid disabling modems after first failure

* Wed Apr 27 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-11mamba
- enable ifcfg-rh plugin

* Thu Feb 10 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-10mamba
- added requirement for dbus

* Tue Feb 08 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-9mamba
- activate service on install

* Fri Feb 04 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-8mamba
- added virtual requirement for dhcpclient

* Mon Jan 31 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-7mamba
- added patch to disable wireless scan if connected (http://nilvec.com/disable-scanning-in-networkmanager-when-connected/)

* Fri Jan 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-6mamba
- install main configuration file (fixes system connection configuration)

* Thu Jan 13 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-5mamba
- create VPN and system-connections directory in configuration dir

* Sun Dec 19 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-4mamba
- added patch to suppress weird log messages about file existence when writing connections

* Thu Dec 09 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-3mamba
- added policykit configuration for system-wide settings

* Thu Dec 02 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-2mamba
- rebuilt with debug package
- added patch that fixes a startup crash when checking wired connections

* Mon Nov 08 2010 Automatic Build System <autodist@mambasoft.it> 0.8.2-1mamba
- automatic update to 0.8.2 by autodist

* Mon Jul 26 2010 Automatic Build System <autodist@mambasoft.it> 0.8.1-1mamba
- automatic update to 0.8.1 by autodist

* Mon Mar 15 2010 Automatic Build System <autodist@mambasoft.it> 0.8-1mamba
- automatic update to 0.8 by autodist

* Tue Nov 24 2009 Automatic Build System <autodist@mambasoft.it> 0.7.2-1mamba
- automatic update to 0.7.2 by autodist

* Sun Apr 19 2009 Automatic Build System <autodist@mambasoft.it> 0.7.1-1mamba
- automatic update by autodist

* Sat Apr 04 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0.99-1mamba
- automatic update by autodist

* Sat Feb 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0.97-1mamba
- automatic update by autodist

* Tue Dec 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0-2mamba
- update to released version

* Fri Jun 13 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0-1mamba
- update to 0.7.0 (svn)

* Fri Jun 13 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.5-3mamba
- added libnm and libnm-devel subpackages

* Mon Jul 16 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.5-2mamba
- rebuilt against wireless_tools 29

* Tue Jul 10 2007 Aleph0 <aleph0@openmamba.org> 0.6.5-1mamba
- update to 0.6.5
- run ldconfig
- dropped patch for dbus: merged upstream
- added missing build requirement

* Fri Apr 06 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.4-1mamba
- update to version 0.6.4 by autospec

* Fri Mar 10 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.5.0-1qilnx
- update to version 0.5.0 by autospec

* Sat Sep 03 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.4-1qilnx
- package created by autospec
